Skip to main content
summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/org.eclipse.osee.framework.messaging.event.res')
-rw-r--r--plugins/org.eclipse.osee.framework.messaging.event.res/jaxb/resMessages.xsd3
-rw-r--r--plugins/org.eclipse.osee.framework.messaging.event.res/src-gen/org/eclipse/osee/framework/messaging/event/res/msgs/RemoteAttributeChange1.java75
-rw-r--r--plugins/org.eclipse.osee.framework.messaging.event.res/src/org/eclipse/osee/framework/messaging/event/res/ResEventManager.java3
3 files changed, 30 insertions, 51 deletions
diff --git a/plugins/org.eclipse.osee.framework.messaging.event.res/jaxb/resMessages.xsd b/plugins/org.eclipse.osee.framework.messaging.event.res/jaxb/resMessages.xsd
index 11e13bf9b60..8c343c69b02 100644
--- a/plugins/org.eclipse.osee.framework.messaging.event.res/jaxb/resMessages.xsd
+++ b/plugins/org.eclipse.osee.framework.messaging.event.res/jaxb/resMessages.xsd
@@ -95,8 +95,7 @@
<xsd:element name="modTypeGuid" type="xsd:string"/>
<xsd:element name="attributeId" type="xsd:int"/>
<xsd:element name="gammaId" type="xsd:int"/>
- <xsd:element name="was" type="xsd:string"/>
- <xsd:element name="is" type="xsd:string"/>
+ <xsd:element name="data" type="xsd:string" maxOccurs="unbounded" minOccurs="1"/>
</xsd:sequence>
</xsd:complexType>
diff --git a/plugins/org.eclipse.osee.framework.messaging.event.res/src/org/eclipse/osee/framework/messaging/event/res/ResEventManager.java b/plugins/org.eclipse.osee.framework.messaging.event.res/src/org/eclipse/osee/framework/messaging/event/res/ResEventManager.java
index 3dfe0aea6f8..bdb0c401b50 100644
--- a/plugins/org.eclipse.osee.framework.messaging.event.res/src/org/eclipse/osee/framework/messaging/event/res/ResEventManager.java
+++ b/plugins/org.eclipse.osee.framework.messaging.event.res/src/org/eclipse/osee/framework/messaging/event/res/ResEventManager.java
@@ -75,7 +75,8 @@ public class ResEventManager implements OseeMessagingStatusCallback {
}
public void sendRemoteEvent(ResMessages resMessage, RemoteEvent remoteEvent) throws Exception {
- System.out.println(String.format(getClass().getSimpleName() + " - sending [%s]", remoteEvent));
+ System.out.println(String.format(getClass().getSimpleName() + " - sending [%s]",
+ remoteEvent.getClass().getSimpleName()));
if (connectionNode != null) {
connectionNode.send(resMessage, remoteEvent, instance);
}

Back to the top
diff --git a/plugins/org.eclipse.osee.framework.messaging.event.res/src-gen/org/eclipse/osee/framework/messaging/event/res/msgs/RemoteAttributeChange1.java b/plugins/org.eclipse.osee.framework.messaging.event.res/src-gen/org/eclipse/osee/framework/messaging/event/res/msgs/RemoteAttributeChange1.java
index 7d17deaa1e9..c775dece632 100644
--- a/plugins/org.eclipse.osee.framework.messaging.event.res/src-gen/org/eclipse/osee/framework/messaging/event/res/msgs/RemoteAttributeChange1.java
+++ b/plugins/org.eclipse.osee.framework.messaging.event.res/src-gen/org/eclipse/osee/framework/messaging/event/res/msgs/RemoteAttributeChange1.java
@@ -2,12 +2,14 @@
// This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, vJAXB 2.1.3 in JDK 1.6
// See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a>
// Any modifications to this file will be lost upon recompilation of the source schema.
-// Generated on: 2010.04.13 at 01:19:00 PM MST
+// Generated on: 2010.04.26 at 12:16:45 PM MST
//
package org.eclipse.osee.framework.messaging.event.res.msgs;
+import java.util.ArrayList;
+import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
@@ -29,8 +31,7 @@ import org.eclipse.osee.framework.messaging.event.res.RemoteEvent;
* &lt;element name="modTypeGuid" type="{http://www.w3.org/2001/XMLSchema}string"/>
* &lt;element name="attributeId" type="{http://www.w3.org/2001/XMLSchema}int"/>
* &lt;element name="gammaId" type="{http://www.w3.org/2001/XMLSchema}int"/>
- * &lt;element name="was" type="{http://www.w3.org/2001/XMLSchema}string"/>
- * &lt;element name="is" type="{http://www.w3.org/2001/XMLSchema}string"/>
+ * &lt;element name="data" type="{http://www.w3.org/2001/XMLSchema}string" maxOccurs="unbounded"/>
* &lt;/sequence>
* &lt;/restriction>
* &lt;/complexContent>
@@ -45,8 +46,7 @@ import org.eclipse.osee.framework.messaging.event.res.RemoteEvent;
"modTypeGuid",
"attributeId",
"gammaId",
- "was",
- "is"
+ "data"
})
public class RemoteAttributeChange1
extends RemoteEvent
@@ -59,9 +59,7 @@ public class RemoteAttributeChange1
protected int attributeId;
protected int gammaId;
@XmlElement(required = true)
- protected String was;
- @XmlElement(required = true)
- protected String is;
+ protected List<String> data;
/**
* Gets the value of the attrTypeGuid property.
@@ -144,51 +142,32 @@ public class RemoteAttributeChange1
}
/**
* Gets the value of the was property.
*
- * @return
- * possible object is
- * {@link String }
- *
- */
- public String getWas() {
- return was;
- }
-
- /**
- * Sets the value of the was property.
+ * <p>
+ * This accessor method returns a reference to the live list,
+ * not a snapshot. Therefore any modification you make to the
+ * returned list will be present inside the JAXB object.
+ * This is why there is not a <CODE>set</CODE> method for the data property.
*
- * @param value
- * allowed object is
- * {@link String }
- *
- */
- public void setWas(String value) {
- this.was = value;
- }
-
- /**
- * Gets the value of the is property.
+ * <p>
+ * For example, to add a new item, do as follows:
+ * <pre>
+ * getData().add(newItem);
+ * </pre>
+ *
+ *
+ * <p>
+ * Objects of the following type(s) are allowed in the list
+ * {@link String }
*
- * @return
- * possible object is
- * {@link String }
- *
- */
- public String getIs() {
- return is;
- }
-
- /**
- * Sets the value of the is property.
*
- * @param value
- * allowed object is
- * {@link String }
- *
*/
- public void setIs(String value) {
- this.is = value;
+ public List<String> getData() {
+ if (data == null) {
+ data = new ArrayList<String>();
+ }
+ return this.data;
}
}
@@ -144,51 +142,32 @@ public class RemoteAttributeChange1
}
/**
- * Gets the value of the was property.
+ * Gets the value of the data property.
*